import unittest, sys
from fose.protocol import UriBuilder
import pkg_resources
from lxml import etree
import requests

### Test Data Section

TESTDOI = '99.789/fosetest.1'
TESTUID = 'a1B2c3D4'
REVIEWCONTENT = 'FOSE Compliance Test Review'


def runtest(testclass):
    suite = unittest.TestLoader().loadTestsFromTestCase(testclass)
    testResult = unittest.TextTestRunner(verbosity=2).run(suite)
    if not testResult.wasSuccessful():
        sys.exit('[fose test wrapper] One or more tests failed!')

# These tests assume that the compliance test data have been installed
class ComplianceTests(unittest.TestCase):

    def setUp(self):
        self.uri = UriBuilder(self.rootUrl)

    def test_Get_review_thread_for_id(self):
		#use protocol url to GET response 
        url = self.uri.forDoi(TESTDOI)
        #actually get file
        response = requests.get(url, headers={'Accept':'text/xml'})
        response.raise_for_status()
		#test schema validation
        schemaFilename = pkg_resources.resource_filename('fose','thread.xsd')
        schema = etree.XMLSchema(file=schemaFilename)
        parser = etree.XMLParser(schema = schema)
        #THREAD = '<?xml version="1.0"?><thread xmlns="http://fose1.org/fose"/>'
        root = etree.fromstring(response.text, parser)
		#use core lib to read this as a model object
		#for each review in thread, test if it is a review by user 'a1B2c3D4'
        # with content 'FOSE Compliance Test Review' 

    def test_Get_user_profile_for_uid(self):
		#use protocol url to GET response 
        url = self.uri.forUser(TESTUID)
        #actually get file
        response = requests.get(url, headers={'Accept':'text/xml'})
        response.raise_for_status()
		#test schema validation
        schemaFilename = pkg_resources.resource_filename('fose','user.xsd')
        schema = etree.XMLSchema(file=schemaFilename)
        parser = etree.XMLParser(schema = schema)
        #THREAD = '<?xml version="1.0"?><thread xmlns="http://fose1.org/fose"/>'
        root = etree.fromstring(response.text, parser)
		#use core lib to read this as a model object
		#for each review by user, test if it is a review 
        # for doi '99.789/fosetest.1' with content 'FOSE Compliance Test Review' 

def run(targetUrl):
    ComplianceTests.rootUrl = targetUrl
    runtest(ComplianceTests)

if __name__ == '__main__':
    unittest.main()



import unittest, sys, os
import pkg_resources

def runtest(testclass):
    suite = unittest.TestLoader().loadTestsFromTestCase(testclass)
    testResult = unittest.TextTestRunner(verbosity=2).run(suite)
    if not testResult.wasSuccessful():
        sys.exit('[fose test wrapper] One or more tests failed!')

def runall():
    runtest(FoseTests)

class FoseTests(unittest.TestCase):

    def test_version(self):
        import fose
        pkgversion = pkg_resources.get_distribution("fose").version
        self.assertEqual(fose.version,pkgversion)

    def test_has_schemas(self):
        import fose
        schemaFilename = pkg_resources.resource_filename('fose','thread.xsd')
        self.assertTrue(os.path.isfile(schemaFilename))

    def test_uribuilder_single_publication_by_doi(self):
        from fose.protocol import UriBuilder
        expected = 'http://base.domain/doi/99.987/abc.1234'
        uriBuilder = UriBuilder('http://base.domain')
        self.assertEqual(expected, uriBuilder.forDoi('99.987/abc.1234'))

if __name__ == '__main__':
    unittest.main()



import sys, argparse
import pkg_resources
import fose.tests
import fose.compliance


def main():
    description='Core package of Framework for Open Science Evaluation.'
    parser = argparse.ArgumentParser(description)
    parser.add_argument('--test', action='store_true',help='Run unit tests.')
    parser.add_argument('--compliance', 
		help='Run compliance tests for the url COMPLIANCE.')
    args = parser.parse_args()
    if args.test:
        fose.tests.runall()
    if args.compliance:
		fose.compliance.run(args.compliance)

version = pkg_resources.get_distribution("fose").version



import urlparse

class UriBuilder(object):

    def __init__(self, providerRootUrl):
        self.root = providerRootUrl

    def forDoi(self, doi):
        doiBase = urlparse.urljoin(self.root, 'doi/')
        return urlparse.urljoin(doiBase, doi)

    def forUser(self, uid):
        userBase = urlparse.urljoin(self.root, 'users/')
        return urlparse.urljoin(userBase, uid)



from setuptools import setup, find_packages
from version import get_git_version


setup(name='fose',
        version=get_git_version(),
        description='Framework for Open Science Evaluation Core Package',
        author='Jasper van den Bosch',
        author_email='jasper.jf.vandenbosch@gmail.com',
        url='https://github.com/ilogue/fose',
        packages=find_packages(),
        test_suite='tests',
        entry_points={
          'console_scripts': ['fose = fose:main',]},
        install_requires=['lxml','requests'],
        package_data={'fose': ['*.xsd']},
      )

